@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,6 +17,9 @@
  */
 
 #include "CServerApp.h"
+#include "CLog.h"
+#include "CArch.h"
+#include "CEventQueue.h"
 
 #if WINAPI_MSWINDOWS
 #include "CMSWindowsServerTaskBarReceiver.h"
@@ -30,6 +34,17 @@
 int
 main(int argc, char** argv) 
 {
+#if SYSAPI_WIN32
+	// record window instance for tray icon, etc
+	CArchMiscWindows::setInstanceWin32(GetModuleHandle(NULL));
+#endif
+	
+	CArch arch;
+	arch.init();
+
+	CLog log;
+	CEventQueue events;
+
 	CServerApp app(createTaskBarReceiver);
 	return app.run(argc, argv);
 }
