@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2003 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2003 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +23,7 @@
 #include "XArch.h"
 #include <string.h>
 #include <shellapi.h>
-#include "CArchAppUtilWindows.h"
+#include "CAppUtilWindows.h"
 
 static const UINT		kAddReceiver     = WM_USER + 10;
 static const UINT		kRemoveReceiver  = WM_USER + 11;
@@ -41,7 +42,23 @@ CArchTaskBarWindows::CArchTaskBarWindows() :
 {
 	// save the singleton instance
 	s_instance    = this;
+}
 
+CArchTaskBarWindows::~CArchTaskBarWindows()
+{
+	if (m_thread != NULL) {
+		PostMessage(m_hwnd, WM_QUIT, 0, 0);
+		ARCH->wait(m_thread, -1.0);
+		ARCH->closeThread(m_thread);
+	}
+	ARCH->closeCondVar(m_condVar);
+	ARCH->closeMutex(m_mutex);
+	s_instance = NULL;
+}
+
+void
+CArchTaskBarWindows::init()
+{
 	// we need a mutex
 	m_mutex       = ARCH->newMutex();
 
@@ -70,18 +87,6 @@ CArchTaskBarWindows::CArchTaskBarWindows() :
 	ARCH->unlockMutex(m_mutex);
 }
 
-CArchTaskBarWindows::~CArchTaskBarWindows()
-{
-	if (m_thread != NULL) {
-		PostMessage(m_hwnd, WM_QUIT, 0, 0);
-		ARCH->wait(m_thread, -1.0);
-		ARCH->closeThread(m_thread);
-	}
-	ARCH->closeCondVar(m_condVar);
-	ARCH->closeMutex(m_mutex);
-	s_instance = NULL;
-}
-
 void
 CArchTaskBarWindows::addDialog(HWND hwnd)
 {
