@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,6 +34,7 @@
 #include <cstdlib>
 #include "CArch.h"
 #include "IPlatformScreen.h"
+#include "CCryptoStream.h"
 
 //
 // CClient
@@ -42,16 +44,13 @@ CEvent::Type			CClient::s_connectedEvent        = CEvent::kUnknown;
 CEvent::Type			CClient::s_connectionFailedEvent = CEvent::kUnknown;
 CEvent::Type			CClient::s_disconnectedEvent     = CEvent::kUnknown;
 
-CClient::CClient(IEventQueue& eventQueue) :
-	m_eventQueue(eventQueue)
-{
-}
-
-CClient::CClient(IEventQueue& eventQueue,
+CClient::CClient(IEventQueue* eventQueue,
 				const CString& name, const CNetworkAddress& address,
 				ISocketFactory* socketFactory,
 				IStreamFilterFactory* streamFilterFactory,
-				CScreen* screen) :
+				CScreen* screen,
+				const CCryptoOptions& crypto) :
+	m_mock(false),
 	m_name(name),
 	m_serverAddress(address),
 	m_socketFactory(socketFactory),
@@ -65,25 +64,26 @@ CClient::CClient(IEventQueue& eventQueue,
 	m_suspended(false),
 	m_connectOnResume(false),
 	m_eventQueue(eventQueue),
-	m_mock(false)
+	m_cryptoStream(NULL),
+	m_crypto(crypto)
 {
 	assert(m_socketFactory != NULL);
 	assert(m_screen        != NULL);
 
 	// register suspend/resume event handlers
-	m_eventQueue.adoptHandler(IScreen::getSuspendEvent(),
+	m_eventQueue->adoptHandler(IScreen::getSuspendEvent(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleSuspend));
-	m_eventQueue.adoptHandler(IScreen::getResumeEvent(),
+	m_eventQueue->adoptHandler(IScreen::getResumeEvent(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleResume));
-	EVENTQUEUE->adoptHandler(IPlatformScreen::getGameDeviceTimingRespEvent(),
+	m_eventQueue->adoptHandler(IPlatformScreen::getGameDeviceTimingRespEvent(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleGameDeviceTimingResp));
-	EVENTQUEUE->adoptHandler(IPlatformScreen::getGameDeviceFeedbackEvent(),
+	m_eventQueue->adoptHandler(IPlatformScreen::getGameDeviceFeedbackEvent(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleGameDeviceFeedback));
@@ -91,13 +91,13 @@ CClient::CClient(IEventQueue& eventQueue,
 
 CClient::~CClient()
 {
-	// HACK: can't disable dtor with mocks
-	if (m_mock)
+	if (m_mock) {
 		return;
+	}
 
-	m_eventQueue.removeHandler(IScreen::getSuspendEvent(),
+	m_eventQueue->removeHandler(IScreen::getSuspendEvent(),
 							  getEventTarget());
-	m_eventQueue.removeHandler(IScreen::getResumeEvent(),
+	m_eventQueue->removeHandler(IScreen::getResumeEvent(),
 							  getEventTarget());
 
 	cleanupTimer();
@@ -146,6 +146,12 @@ CClient::connect()
 		}
 		m_stream = new CPacketStreamFilter(m_stream, true);
 
+		if (m_crypto.m_mode != kDisabled) {
+			m_cryptoStream = new CCryptoStream(
+				EVENTQUEUE, m_stream, m_crypto, true);
+			m_stream = m_cryptoStream;
+		}
+
 		// connect
 		LOG((CLOG_DEBUG1 "connecting to server"));
 		setupConnecting();
@@ -187,6 +193,14 @@ CClient::handshakeComplete()
 	sendEvent(getConnectedEvent(), NULL);
 }
 
+void
+CClient::setDecryptIv(const UInt8* iv)
+{
+	if (m_cryptoStream != NULL) {
+		m_cryptoStream->setDecryptIv(iv);
+	}
+}
+
 bool
 CClient::isConnected() const
 {
@@ -432,7 +446,7 @@ CClient::sendClipboard(ClipboardID id)
 void
 CClient::sendEvent(CEvent::Type type, void* data)
 {
-	m_eventQueue.addEvent(CEvent(type, getEventTarget(), data));
+	m_eventQueue->addEvent(CEvent(type, getEventTarget(), data));
 }
 
 void
@@ -441,7 +455,7 @@ CClient::sendConnectionFailedEvent(const char* msg)
 	CFailInfo* info = new CFailInfo(msg);
 	info->m_retry = true;
 	CEvent event(getConnectionFailedEvent(), getEventTarget(), info, CEvent::kDontFreeData);
-	EVENTQUEUE->addEvent(event);
+	m_eventQueue->addEvent(event);
 }
 
 void
@@ -449,11 +463,11 @@ CClient::setupConnecting()
 {
 	assert(m_stream != NULL);
 
-	m_eventQueue.adoptHandler(IDataSocket::getConnectedEvent(),
+	m_eventQueue->adoptHandler(IDataSocket::getConnectedEvent(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleConnected));
-	m_eventQueue.adoptHandler(IDataSocket::getConnectionFailedEvent(),
+	m_eventQueue->adoptHandler(IDataSocket::getConnectionFailedEvent(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleConnectionFailed));
@@ -464,23 +478,23 @@ CClient::setupConnection()
 {
 	assert(m_stream != NULL);
 
-	m_eventQueue.adoptHandler(ISocket::getDisconnectedEvent(),
+	m_eventQueue->adoptHandler(ISocket::getDisconnectedEvent(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleDisconnected));
-	m_eventQueue.adoptHandler(m_stream->getInputReadyEvent(),
+	m_eventQueue->adoptHandler(m_stream->getInputReadyEvent(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleHello));
-	m_eventQueue.adoptHandler(m_stream->getOutputErrorEvent(),
+	m_eventQueue->adoptHandler(m_stream->getOutputErrorEvent(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleOutputError));
-	m_eventQueue.adoptHandler(m_stream->getInputShutdownEvent(),
+	m_eventQueue->adoptHandler(m_stream->getInputShutdownEvent(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleDisconnected));
-	m_eventQueue.adoptHandler(m_stream->getOutputShutdownEvent(),
+	m_eventQueue->adoptHandler(m_stream->getOutputShutdownEvent(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleDisconnected));
@@ -492,12 +506,12 @@ CClient::setupScreen()
 	assert(m_server == NULL);
 
 	m_ready  = false;
-	m_server = new CServerProxy(this, m_stream, *EVENTQUEUE);
-	m_eventQueue.adoptHandler(IScreen::getShapeChangedEvent(),
+	m_server = new CServerProxy(this, m_stream, m_eventQueue);
+	m_eventQueue->adoptHandler(IScreen::getShapeChangedEvent(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleShapeChanged));
-	m_eventQueue.adoptHandler(IScreen::getClipboardGrabbedEvent(),
+	m_eventQueue->adoptHandler(IScreen::getClipboardGrabbedEvent(),
 							getEventTarget(),
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleClipboardGrabbed));
@@ -508,8 +522,8 @@ CClient::setupTimer()
 {
 	assert(m_timer == NULL);
 
-	m_timer = m_eventQueue.newOneShotTimer(15.0, NULL);
-	m_eventQueue.adoptHandler(CEvent::kTimer, m_timer,
+	m_timer = m_eventQueue->newOneShotTimer(15.0, NULL);
+	m_eventQueue->adoptHandler(CEvent::kTimer, m_timer,
 							new TMethodEventJob<CClient>(this,
 								&CClient::handleConnectTimeout));
 }
@@ -518,9 +532,9 @@ void
 CClient::cleanupConnecting()
 {
 	if (m_stream != NULL) {
-		m_eventQueue.removeHandler(IDataSocket::getConnectedEvent(),
+		m_eventQueue->removeHandler(IDataSocket::getConnectedEvent(),
 							m_stream->getEventTarget());
-		m_eventQueue.removeHandler(IDataSocket::getConnectionFailedEvent(),
+		m_eventQueue->removeHandler(IDataSocket::getConnectionFailedEvent(),
 							m_stream->getEventTarget());
 	}
 }
@@ -529,15 +543,15 @@ void
 CClient::cleanupConnection()
 {
 	if (m_stream != NULL) {
-		m_eventQueue.removeHandler(m_stream->getInputReadyEvent(),
+		m_eventQueue->removeHandler(m_stream->getInputReadyEvent(),
 							m_stream->getEventTarget());
-		m_eventQueue.removeHandler(m_stream->getOutputErrorEvent(),
+		m_eventQueue->removeHandler(m_stream->getOutputErrorEvent(),
 							m_stream->getEventTarget());
-		m_eventQueue.removeHandler(m_stream->getInputShutdownEvent(),
+		m_eventQueue->removeHandler(m_stream->getInputShutdownEvent(),
 							m_stream->getEventTarget());
-		m_eventQueue.removeHandler(m_stream->getOutputShutdownEvent(),
+		m_eventQueue->removeHandler(m_stream->getOutputShutdownEvent(),
 							m_stream->getEventTarget());
-		m_eventQueue.removeHandler(ISocket::getDisconnectedEvent(),
+		m_eventQueue->removeHandler(ISocket::getDisconnectedEvent(),
 							m_stream->getEventTarget());
 		delete m_stream;
 		m_stream = NULL;
@@ -552,9 +566,9 @@ CClient::cleanupScreen()
 			m_screen->disable();
 			m_ready = false;
 		}
-		m_eventQueue.removeHandler(IScreen::getShapeChangedEvent(),
+		m_eventQueue->removeHandler(IScreen::getShapeChangedEvent(),
 							getEventTarget());
-		m_eventQueue.removeHandler(IScreen::getClipboardGrabbedEvent(),
+		m_eventQueue->removeHandler(IScreen::getClipboardGrabbedEvent(),
 							getEventTarget());
 		delete m_server;
 		m_server = NULL;
@@ -565,8 +579,8 @@ void
 CClient::cleanupTimer()
 {
 	if (m_timer != NULL) {
-		m_eventQueue.removeHandler(CEvent::kTimer, m_timer);
-		m_eventQueue.deleteTimer(m_timer);
+		m_eventQueue->removeHandler(CEvent::kTimer, m_timer);
+		m_eventQueue->deleteTimer(m_timer);
 		m_timer = NULL;
 	}
 }
@@ -696,7 +710,7 @@ CClient::handleHello(const CEvent&, void*)
 	// receive another event for already pending messages so we fake
 	// one.
 	if (m_stream->isReady()) {
-		m_eventQueue.addEvent(CEvent(m_stream->getInputReadyEvent(),
+		m_eventQueue->addEvent(CEvent(m_stream->getInputReadyEvent(),
 							m_stream->getEventTarget()));
 	}
 }
