@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,12 +29,13 @@
 #include "XBase.h"
 #include <memory>
 #include <cstring>
+#include "CCryptoStream.h"
 
 //
 // CServerProxy
 //
 
-CServerProxy::CServerProxy(CClient* client, synergy::IStream* stream, IEventQueue& eventQueue) :
+CServerProxy::CServerProxy(CClient* client, synergy::IStream* stream, IEventQueue* eventQueue) :
 	m_client(client),
 	m_stream(stream),
 	m_seqNum(0),
@@ -57,7 +59,7 @@ CServerProxy::CServerProxy(CClient* client, synergy::IStream* stream, IEventQueu
 		m_modifierTranslationTable[id] = id;
 
 	// handle data on stream
-	m_eventQueue.adoptHandler(m_stream->getInputReadyEvent(),
+	m_eventQueue->adoptHandler(m_stream->getInputReadyEvent(),
 							m_stream->getEventTarget(),
 							new TMethodEventJob<CServerProxy>(this,
 								&CServerProxy::handleData));
@@ -69,7 +71,7 @@ CServerProxy::CServerProxy(CClient* client, synergy::IStream* stream, IEventQueu
 CServerProxy::~CServerProxy()
 {
 	setKeepAliveRate(-1.0);
-	m_eventQueue.removeHandler(m_stream->getInputReadyEvent(),
+	m_eventQueue->removeHandler(m_stream->getInputReadyEvent(),
 							m_stream->getEventTarget());
 }
 
@@ -77,14 +79,14 @@ void
 CServerProxy::resetKeepAliveAlarm()
 {
 	if (m_keepAliveAlarmTimer != NULL) {
-		m_eventQueue.removeHandler(CEvent::kTimer, m_keepAliveAlarmTimer);
-		m_eventQueue.deleteTimer(m_keepAliveAlarmTimer);
+		m_eventQueue->removeHandler(CEvent::kTimer, m_keepAliveAlarmTimer);
+		m_eventQueue->deleteTimer(m_keepAliveAlarmTimer);
 		m_keepAliveAlarmTimer = NULL;
 	}
 	if (m_keepAliveAlarm > 0.0) {
 		m_keepAliveAlarmTimer =
-			m_eventQueue.newOneShotTimer(m_keepAliveAlarm, NULL);
-		m_eventQueue.adoptHandler(CEvent::kTimer, m_keepAliveAlarmTimer,
+			m_eventQueue->newOneShotTimer(m_keepAliveAlarm, NULL);
+		m_eventQueue->adoptHandler(CEvent::kTimer, m_keepAliveAlarmTimer,
 							new TMethodEventJob<CServerProxy>(this,
 								&CServerProxy::handleKeepAliveAlarm));
 	}
@@ -303,6 +305,10 @@ CServerProxy::parseMessage(const UInt8* code)
 		gameDeviceTimingReq();
 	}
 
+	else if (memcmp(code, kMsgDCryptoIv, 4) == 0) {
+		cryptoIv();
+	}
+
 	else if (memcmp(code, kMsgCClose, 4) == 0) {
 		// server wants us to hangup
 		LOG((CLOG_DEBUG1 "recv close"));
@@ -823,6 +829,18 @@ CServerProxy::gameDeviceTimingReq()
 	m_client->gameDeviceTimingReq();
 }
 
+void
+CServerProxy::cryptoIv()
+{
+	// parse
+	CString s;
+	CProtocolUtil::readf(m_stream, kMsgDCryptoIv + 4, &s);
+	LOG((CLOG_DEBUG2 "recv crypto iv size=%i", s.size()));
+
+	// forward
+	m_client->setDecryptIv(reinterpret_cast<const UInt8*>(s.c_str()));
+}
+
 void
 CServerProxy::screensaver()
 {
