@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,7 +42,7 @@ public:
 	Process messages from the server on \p stream and forward to
 	\p client.
 	*/
-	CServerProxy(CClient* client, synergy::IStream* stream, IEventQueue& eventQueue);
+	CServerProxy(CClient* client, synergy::IStream* stream, IEventQueue* eventQueue);
 	~CServerProxy();
 
 	//! @name manipulators
@@ -55,6 +56,10 @@ public:
 
 	//@}
 
+#ifdef TEST_ENV
+	void				handleDataForTest() { handleData(CEvent(), NULL); }
+#endif
+
 protected:
 	enum EResult { kOkay, kUnknown, kDisconnect };
 	EResult				parseHandshakeMessage(const UInt8* code);
@@ -71,7 +76,7 @@ private:
 
 	// modifier key translation
 	KeyID				translateKey(KeyID) const;
-	KeyModifierMask		translateModifierMask(KeyModifierMask) const;
+	KeyModifierMask			translateModifierMask(KeyModifierMask) const;
 
 	// event handlers
 	void				handleData(const CEvent&, void*);
@@ -94,6 +99,7 @@ private:
 	void				gameDeviceSticks();
 	void				gameDeviceTriggers();
 	void				gameDeviceTimingReq();
+	void				cryptoIv();
 	void				screensaver();
 	void				resetOptions();
 	void				setOptions();
@@ -104,7 +110,7 @@ private:
 	typedef EResult (CServerProxy::*MessageParser)(const UInt8*);
 
 	CClient*			m_client;
-	synergy::IStream*			m_stream;
+	synergy::IStream*		m_stream;
 
 	UInt32				m_seqNum;
 
@@ -115,13 +121,13 @@ private:
 
 	bool				m_ignoreMouse;
 
-	KeyModifierID		m_modifierTranslationTable[kKeyModifierIDLast];
+	KeyModifierID			m_modifierTranslationTable[kKeyModifierIDLast];
 
 	double				m_keepAliveAlarm;
-	CEventQueueTimer*	m_keepAliveAlarmTimer;
+	CEventQueueTimer*		m_keepAliveAlarmTimer;
 
-	MessageParser		m_parser;
-	IEventQueue&		m_eventQueue;
+	MessageParser			m_parser;
+	IEventQueue*			m_eventQueue;
 };
 
 #endif
