@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2004 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2004 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,6 +20,7 @@
 #define CSTREAMFILTER_H
 
 #include "IStream.h"
+#include "IEventQueue.h"
 
 //! A stream filter
 /*!
@@ -32,8 +34,8 @@ public:
 	this object takes ownership of the stream and will delete it in the
 	d'tor.
 	*/
-	CStreamFilter(synergy::IStream* stream, bool adoptStream = true);
-	~CStreamFilter();
+	CStreamFilter(IEventQueue* eventQueue, synergy::IStream* stream, bool adoptStream = true);
+	virtual ~CStreamFilter();
 
 	// IStream overrides
 	// These all just forward to the underlying stream except getEventTarget.
