@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,14 +38,6 @@
 #include "CArchMiscWindows.h"
 #include <string.h>
 #include <pbt.h>
-#include "GameDeviceTypes.h"
-
-#if GAME_DEVICE_SUPPORT
-#define WIN32_LEAN_AND_MEAN
-#include <Windows.h>
-#include "XInput.h"
-#include "XInputHook.h"
-#endif
 
 //
 // add backwards compatible multihead support (and suppress bogus warning).
@@ -81,19 +74,18 @@
 #define PBT_APMRESUMEAUTOMATIC	0x0012
 #endif
 
-#if GAME_DEVICE_SUPPORT
-typedef DWORD (WINAPI *XInputGetStateFunc)(DWORD, XINPUT_STATE*);
-typedef DWORD (WINAPI *XInputSetStateFunc)(DWORD, XINPUT_VIBRATION*);
-#endif
-
 //
 // CMSWindowsScreen
 //
 
-HINSTANCE				CMSWindowsScreen::s_instance = NULL;
+HINSTANCE				CMSWindowsScreen::s_windowInstance = NULL;
 CMSWindowsScreen*		CMSWindowsScreen::s_screen   = NULL;
 
-CMSWindowsScreen::CMSWindowsScreen(bool isPrimary, bool noHooks, bool gameDevice) :
+CMSWindowsScreen::CMSWindowsScreen(
+	bool isPrimary,
+	bool noHooks,
+	const CGameDeviceInfo& gameDeviceInfo,
+	bool stopOnDeskSwitch) :
 	m_isPrimary(isPrimary),
 	m_noHooks(noHooks),
 	m_is95Family(CArchMiscWindows::isWindows95Family()),
@@ -119,47 +111,26 @@ CMSWindowsScreen::CMSWindowsScreen(bool isPrimary, bool noHooks, bool gameDevice
 	m_hookLibrary(NULL),
 	m_keyState(NULL),
 	m_hasMouse(GetSystemMetrics(SM_MOUSEPRESENT) != 0),
-	m_showingMouse(false)
-#if GAME_DEVICE_SUPPORT
-	// @todo - move game support stuff to new class
-	, m_xInputPollThread(NULL)
-	, m_xInputTimingThread(NULL)
-	, m_xInputFeedbackThread(NULL)
-	, m_gameButtonsLast(0)
-	, m_gameLeftTriggerLast(0)
-	, m_gameRightTriggerLast(0)
-	, m_gameLeftStickXLast(0)
-	, m_gameLeftStickYLast(0)
-	, m_gameRightStickXLast(0)
-	, m_gameRightStickYLast(0)
-	, m_gameLastTimingSent(0)
-	, m_gameTimingWaiting(false)
-	, m_gameFakeLag(0)
-	, m_gamePollFreq(kGamePollFreqDefault)
-	, m_gamePollFreqAdjust(0)
-	, m_gameFakeLagMin(kGamePollFreqDefault)
-	, m_gameTimingStarted(false)
-	, m_gameTimingFirst(0)
-	, m_gameFakeLagLast(0)
-	, m_gameTimingCalibrated(false)
-	, m_gameDevice(gameDevice)
-	, m_xinputModule(NULL)
-#endif
+	m_showingMouse(false),
+	m_gameDeviceInfo(gameDeviceInfo),
+	m_gameDevice(NULL)
 {
-	assert(s_instance != NULL);
+	assert(s_windowInstance != NULL);
 	assert(s_screen   == NULL);
 
 	s_screen = this;
 	try {
-		if (m_isPrimary) {
+		if (m_isPrimary && !m_noHooks) {
 			m_hookLibrary = openHookLibrary("synrgyhk");
 		}
 		m_screensaver = new CMSWindowsScreenSaver();
 		m_desks       = new CMSWindowsDesks(
 							m_isPrimary, m_noHooks,
 							m_hookLibrary, m_screensaver,
+							*EVENTQUEUE,
 							new TMethodJob<CMSWindowsScreen>(this,
-								&CMSWindowsScreen::updateKeysCB));
+								&CMSWindowsScreen::updateKeysCB),
+							stopOnDeskSwitch);
 		m_keyState    = new CMSWindowsKeyState(m_desks, getEventTarget());
 		updateScreenShape();
 		m_class       = createWindowClass();
@@ -174,7 +145,10 @@ CMSWindowsScreen::CMSWindowsScreen(bool isPrimary, bool noHooks, bool gameDevice
 		delete m_screensaver;
 		destroyWindow(m_window);
 		destroyClass(m_class);
-		closeHookLibrary(m_hookLibrary);
+
+		if (m_hookLibrary != NULL)
+			closeHookLibrary(m_hookLibrary);
+
 		s_screen = NULL;
 		throw;
 	}
@@ -187,33 +161,24 @@ CMSWindowsScreen::CMSWindowsScreen(bool isPrimary, bool noHooks, bool gameDevice
 	// install the platform event queue
 	EVENTQUEUE->adoptBuffer(new CMSWindowsEventQueueBuffer);
 
+	if ((gameDeviceInfo.m_mode == CGameDeviceInfo::kGameModeXInput) &&
+		(gameDeviceInfo.m_poll != CGameDeviceInfo::kGamePollDynamic))
+		LOG((CLOG_WARN "only dynamic polling is supported with xnput."));
+
+	if ((gameDeviceInfo.m_mode == CGameDeviceInfo::kGameModeJoyInfoEx) &&
+		(gameDeviceInfo.m_poll != CGameDeviceInfo::kGamePollStatic))
+		LOG((CLOG_WARN "only static polling is supported with joyinfoex."));
+
+	if (m_gameDeviceInfo.m_mode == CGameDeviceInfo::kGameModeXInput) {
 #if GAME_DEVICE_SUPPORT
-	if (m_gameDevice)
-	{
-		m_xinputModule = LoadLibrary("xinput1_3.dll");
-		if (m_xinputModule == NULL)
-		{
-			throw XScreenXInputFailure("could not load xinput library.");
-		}
-
-		if (m_isPrimary)
-		{
-			// only capture xinput on the server.
-			m_xInputPollThread = new CThread(new TMethodJob<CMSWindowsScreen>(
-				this, &CMSWindowsScreen::xInputPollThread));
-		}
-		else
-		{
-			// check for queued timing requests on client.
-			m_xInputTimingThread = new CThread(new TMethodJob<CMSWindowsScreen>(
-				this, &CMSWindowsScreen::xInputTimingThread));
-
-			// check for waiting feedback state on client.
-			m_xInputFeedbackThread = new CThread(new TMethodJob<CMSWindowsScreen>(
-				this, &CMSWindowsScreen::xInputFeedbackThread));
-		}
-	}
+		m_gameDevice = new CMSWindowsXInput(this, gameDeviceInfo);
+#else if _AMD64_
+		LOG((CLOG_WARN "xinput game device mode not supported for 64-bit."));
 #endif
+	}
+	else {
+		m_gameDevice = new CEventGameDevice(getEventTarget());
+	}
 }
 
 CMSWindowsScreen::~CMSWindowsScreen()
@@ -228,23 +193,29 @@ CMSWindowsScreen::~CMSWindowsScreen()
 	delete m_screensaver;
 	destroyWindow(m_window);
 	destroyClass(m_class);
-	closeHookLibrary(m_hookLibrary);
+
+	if (m_gameDevice != NULL)
+		delete m_gameDevice;
+
+	if (m_hookLibrary != NULL)
+		closeHookLibrary(m_hookLibrary);
+
 	s_screen = NULL;
 }
 
 void
-CMSWindowsScreen::init(HINSTANCE instance)
+CMSWindowsScreen::init(HINSTANCE windowInstance)
 {
-	assert(s_instance == NULL);
-	assert(instance   != NULL);
+	assert(s_windowInstance == NULL);
+	assert(windowInstance   != NULL);
 
-	s_instance = instance;
+	s_windowInstance = windowInstance;
 }
 
 HINSTANCE
-CMSWindowsScreen::getInstance()
+CMSWindowsScreen::getWindowInstance()
 {
-	return s_instance;
+	return s_windowInstance;
 }
 
 void
@@ -265,11 +236,13 @@ CMSWindowsScreen::enable()
 	m_desks->enable();
 
 	if (m_isPrimary) {
-		// set jump zones
-		m_hookLibraryLoader.m_setZone(m_x, m_y, m_w, m_h, getJumpZoneSize());
+		if (m_hookLibrary != NULL) {
+			// set jump zones
+			m_hookLibraryLoader.m_setZone(m_x, m_y, m_w, m_h, getJumpZoneSize());
 
-		// watch jump zones
-		m_hookLibraryLoader.m_setMode(kHOOK_WATCH_JUMP_ZONE);
+			// watch jump zones
+			m_hookLibraryLoader.m_setMode(kHOOK_WATCH_JUMP_ZONE);
+		}
 	}
 	else {
 		// prevent the system from entering power saving modes.  if
@@ -286,8 +259,10 @@ CMSWindowsScreen::disable()
 	m_desks->disable();
 
 	if (m_isPrimary) {
-		// disable hooks
-		m_hookLibraryLoader.m_setMode(kHOOK_DISABLE);
+		if (m_hookLibrary != NULL) {
+			// disable hooks
+			m_hookLibraryLoader.m_setMode(kHOOK_DISABLE);
+		}
 
 		// enable special key sequences on win95 family
 		enableSpecialKeys(true);
@@ -324,8 +299,10 @@ CMSWindowsScreen::enter()
 		// enable special key sequences on win95 family
 		enableSpecialKeys(true);
 
-		// watch jump zones
-		m_hookLibraryLoader.m_setMode(kHOOK_WATCH_JUMP_ZONE);
+		if (m_hookLibrary != NULL) {
+			// watch jump zones
+			m_hookLibraryLoader.m_setMode(kHOOK_WATCH_JUMP_ZONE);
+		}
 
 		// all messages prior to now are invalid
 		nextMark();
@@ -377,8 +354,10 @@ CMSWindowsScreen::leave()
 		// reflected in the internal keyboard state.
 		m_keyState->saveModifiers();
 
-		// capture events
-		m_hookLibraryLoader.m_setMode(kHOOK_RELAY_EVENTS);
+		if (m_hookLibrary != NULL) {
+			// capture events
+			m_hookLibraryLoader.m_setMode(kHOOK_RELAY_EVENTS);
+		}
 	}
 
 	// now off screen
@@ -532,7 +511,9 @@ CMSWindowsScreen::reconfigure(UInt32 activeSides)
 	assert(m_isPrimary);
 
 	LOG((CLOG_DEBUG "active sides: %x", activeSides));
-	m_hookLibraryLoader.m_setSides(activeSides);
+
+	if (m_hookLibrary != NULL)
+		m_hookLibraryLoader.m_setSides(activeSides);
 }
 
 void
@@ -566,7 +547,9 @@ CMSWindowsScreen::registerHotKey(KeyID key, KeyModifierMask mask)
 	// only allow certain modifiers
 	if ((mask & ~(KeyModifierShift | KeyModifierControl |
 				  KeyModifierAlt   | KeyModifierSuper)) != 0) {
-		LOG((CLOG_WARN "could not map hotkey id=%04x mask=%04x", key, mask));
+		// this should be a warning, but this can confuse users,
+		// as this warning happens almost always.
+		LOG((CLOG_DEBUG "could not map hotkey id=%04x mask=%04x", key, mask));
 		return 0;
 	}
 
@@ -592,7 +575,9 @@ CMSWindowsScreen::registerHotKey(KeyID key, KeyModifierMask mask)
 	UINT vk = m_keyState->mapKeyToVirtualKey(key);
 	if (key != kKeyNone && vk == 0) {
 		// can't map key
-		LOG((CLOG_WARN "could not map hotkey id=%04x mask=%04x", key, mask));
+		// this should be a warning, but this can confuse users,
+		// as this warning happens almost always.
+		LOG((CLOG_DEBUG "could not map hotkey id=%04x mask=%04x", key, mask));
 		return 0;
 	}
 
@@ -721,7 +706,19 @@ CMSWindowsScreen::getCursorCenter(SInt32& x, SInt32& y) const
 }
 
 void
-CMSWindowsScreen::fakeMouseButton(ButtonID id, bool press) const
+CMSWindowsScreen::gameDeviceTimingResp(UInt16 freq)
+{
+	m_gameDevice->gameDeviceTimingResp(freq);
+}
+
+void
+CMSWindowsScreen::gameDeviceFeedback(GameDeviceID id, UInt16 m1, UInt16 m2)
+{
+	m_gameDevice->gameDeviceFeedback(id, m1, m2);
+}
+
+void
+CMSWindowsScreen::fakeMouseButton(ButtonID id, bool press)
 {
 	m_desks->fakeMouseButton(id, press);
 }
@@ -747,162 +744,29 @@ CMSWindowsScreen::fakeMouseWheel(SInt32 xDelta, SInt32 yDelta) const
 void
 CMSWindowsScreen::fakeGameDeviceButtons(GameDeviceID id, GameDeviceButton buttons) const
 {
-#if GAME_DEVICE_SUPPORT
-	if (m_gameDevice)
-	{
-		LOG((CLOG_DEBUG "fake game device buttons id=%d buttons=%d", id, buttons));
-		SetXInputButtons(id, buttons);
-	}
-#endif
+	LOG((CLOG_DEBUG "fake game device buttons id=%d buttons=%d", id, buttons));
+	m_gameDevice->fakeGameDeviceButtons(id, buttons);
 }
 
 void
 CMSWindowsScreen::fakeGameDeviceSticks(GameDeviceID id, SInt16 x1, SInt16 y1, SInt16 x2, SInt16 y2) const
 {
-#if GAME_DEVICE_SUPPORT
-	if (m_gameDevice)
-	{
-		LOG((CLOG_DEBUG "fake game device sticks id=%d s1=%+d,%+d s2=%+d,%+d", id, x1, y1, x2, y2));
-		SetXInputSticks(id, x1, y1, x2, y2);
-	}
-#endif
+	LOG((CLOG_DEBUG "fake game device sticks id=%d s1=%+d,%+d s2=%+d,%+d", id, x1, y1, x2, y2));
+	m_gameDevice->fakeGameDeviceSticks(id, x1, y1, x2, y2);
 }
 
 void
 CMSWindowsScreen::fakeGameDeviceTriggers(GameDeviceID id, UInt8 t1, UInt8 t2) const
 {
-#if GAME_DEVICE_SUPPORT
-	if (m_gameDevice)
-	{
-		LOG((CLOG_DEBUG "fake game device triggers id=%d t1=%d t2=%d", id, t1, t2));
-		SetXInputTriggers(id, t1, t2);
-	}
-#endif
+	LOG((CLOG_DEBUG "fake game device triggers id=%d t1=%d t2=%d", id, t1, t2));
+	m_gameDevice->fakeGameDeviceTriggers(id, t1, t2);
 }
 
 void
 CMSWindowsScreen::queueGameDeviceTimingReq() const
 {
-#if GAME_DEVICE_SUPPORT
-	if (m_gameDevice)
-	{
-		LOG((CLOG_DEBUG "queue game device timing request"));
-		QueueXInputTimingReq();
-	}
-#endif
-}
-
-void
-CMSWindowsScreen::gameDeviceTimingResp(UInt16 freq)
-{
-#if GAME_DEVICE_SUPPORT
-	if (!m_gameTimingStarted)
-	{
-		// record when timing started for calibration period.
-		m_gameTimingFirst = (UInt16)(ARCH->time() * 1000);
-		m_gameTimingStarted = true;
-	}
-
-	m_gameTimingWaiting = false;
-	m_gameFakeLagLast = m_gameFakeLag;
-	m_gameFakeLag = (UInt16)((ARCH->time() - m_gameLastTimingSent) * 1000);
-	m_gameFakeLagRecord.push_back(m_gameFakeLag);
-
-	if (m_gameFakeLag < m_gameFakeLagMin)
-	{
-		// record the lowest value so that the poll frequency
-		// is adjusted to track.
-		m_gameFakeLagMin = m_gameFakeLag;
-	}
-	else if (m_gameFakeLag > (m_gameFakeLagLast * 2))
-	{
-		// if fake lag has increased significantly since the last
-		// timing, then we must have reached the safe minimum.
-		m_gameFakeLagMin = m_gameFakeLagLast;
-	}
-
-	// only change poll frequency if it's a sensible value.
-	if (freq > kGamePollFreqMin && freq < kGamePollFreqMax)
-	{
-		m_gamePollFreq = freq;
-	}
-
-	UInt16 timeSinceStart = ((UInt16)(ARCH->time() * 1000) - m_gameTimingFirst);
-	if (!m_gameTimingCalibrated && (timeSinceStart < kGameCalibrationPeriod))
-	{
-		// during the calibration period, increase polling speed
-		// to try and find the lowest lag value.
-		m_gamePollFreqAdjust = 1;
-		LOG((CLOG_DEBUG2 "calibrating game device poll frequency, start=%d, now=%d, since=%d",
-			m_gameTimingFirst, (int)(ARCH->time() * 1000), timeSinceStart));
-	}
-	else
-	{
-		// @bug - calibration seems to re-occur after a period of time,
-		// though, this would actually be a nice feature (but could be
-		// a bit risky -- could cause poor game play)... setting this
-		// stops calibration from happening again.
-		m_gameTimingCalibrated = true;
-
-		// only adjust poll frequency if outside desired limits.
-		m_gamePollFreqAdjust = 0;
-		if (m_gameFakeLag > m_gameFakeLagMin * 3)
-		{
-			m_gamePollFreqAdjust = 1;
-		}
-		else if (m_gameFakeLag < m_gameFakeLagMin)
-		{
-			m_gamePollFreqAdjust = -1;
-		}
-	}
-
-	LOG((CLOG_DEBUG3 "game device timing, lag=%dms, freq=%dms, adjust=%dms, min=%dms",
-		m_gameFakeLag, m_gamePollFreq, m_gamePollFreqAdjust, m_gameFakeLagMin));
-
-	if (m_gameFakeLagRecord.size() >= kGameLagRecordMax)
-	{
-		UInt16 v, min = 65535, max = 0, total = 0;
-		std::vector<UInt16>::iterator it;
-		for (it = m_gameFakeLagRecord.begin(); it < m_gameFakeLagRecord.end(); ++it)
-		{
-			v = *it;
-			if (v < min)
-			{
-				min = v;
-			}
-			if (v > max)
-			{
-				max = v;
-			}
-			total += v;
-		}
-
-		LOG((CLOG_INFO "game device timing, min=%dms, max=%dms, avg=%dms",
-			min, max, (UInt16)(total / m_gameFakeLagRecord.size())));
-		m_gameFakeLagRecord.clear();
-	}
-#endif
-}
-
-void
-CMSWindowsScreen::gameDeviceFeedback(GameDeviceID id, UInt16 m1, UInt16 m2)
-{
-#if GAME_DEVICE_SUPPORT
-
-	XInputSetStateFunc xInputSetStateFunc =
-		(XInputSetStateFunc)GetProcAddress(m_xinputModule, "XInputSetState");
-
-	if (xInputSetStateFunc == NULL)
-	{
-		throw XScreenXInputFailure("could not get function address: XInputSetState");
-	}
-
-	XINPUT_VIBRATION vibration;
-	ZeroMemory(&vibration, sizeof(XINPUT_VIBRATION));
-	vibration.wLeftMotorSpeed = m1;
-	vibration.wRightMotorSpeed = m2;
-	xInputSetStateFunc(id, &vibration);
-#endif
+	LOG((CLOG_DEBUG "queue game device timing request"));
+	m_gameDevice->queueGameDeviceTimingReq();
 }
 
 void
@@ -969,7 +833,7 @@ CMSWindowsScreen::createBlankCursor() const
 	UInt8* cursorXOR = new UInt8[ch * ((cw + 31) >> 2)];
 	memset(cursorAND, 0xff, ch * ((cw + 31) >> 2));
 	memset(cursorXOR, 0x00, ch * ((cw + 31) >> 2));
-	HCURSOR c = CreateCursor(s_instance, 0, 0, cw, ch, cursorAND, cursorXOR);
+	HCURSOR c = CreateCursor(s_windowInstance, 0, 0, cw, ch, cursorAND, cursorXOR);
 	delete[] cursorXOR;
 	delete[] cursorAND;
 	return c;
@@ -992,7 +856,7 @@ CMSWindowsScreen::createWindowClass() const
 	classInfo.lpfnWndProc   = &CMSWindowsScreen::wndProc;
 	classInfo.cbClsExtra    = 0;
 	classInfo.cbWndExtra    = 0;
-	classInfo.hInstance     = s_instance;
+	classInfo.hInstance     = s_windowInstance;
 	classInfo.hIcon         = NULL;
 	classInfo.hCursor       = NULL;
 	classInfo.hbrBackground = NULL;
@@ -1006,7 +870,7 @@ void
 CMSWindowsScreen::destroyClass(ATOM windowClass) const
 {
 	if (windowClass != 0) {
-		UnregisterClass(reinterpret_cast<LPCTSTR>(windowClass), s_instance);
+		UnregisterClass(reinterpret_cast<LPCTSTR>(windowClass), s_windowInstance);
 	}
 }
 
@@ -1021,7 +885,7 @@ CMSWindowsScreen::createWindow(ATOM windowClass, const char* name) const
 								WS_POPUP,
 								0, 0, 1, 1,
 								NULL, NULL,
-								s_instance,
+								s_windowInstance,
 								NULL);
 	if (window == NULL) {
 		LOG((CLOG_ERR "failed to create window: %d", GetLastError()));
@@ -1978,158 +1842,6 @@ CMSWindowsScreen::wndProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
 	return result;
 }
 
-#if GAME_DEVICE_SUPPORT
-
-void
-CMSWindowsScreen::xInputPollThread(void*)
-{
-	LOG((CLOG_DEBUG "xinput poll thread started"));
-
-	XInputGetStateFunc xInputGetStateFunc = 
-		(XInputGetStateFunc)GetProcAddress(m_xinputModule, "XInputGetState");
-
-	if (xInputGetStateFunc == NULL)
-	{
-		throw XScreenXInputFailure("could not get function address: XInputGetState");
-	}
-
-	int index = 0;
-	XINPUT_STATE state;
-	bool end = false;
-	while (!end)
-	{
-		ZeroMemory(&state, sizeof(XINPUT_STATE));
-		DWORD result = xInputGetStateFunc(index, &state);
-
-		// timeout the timing request after 10 seconds
-		if (m_gameTimingWaiting && (ARCH->time() - m_gameLastTimingSent > 2))
-		{
-			m_gameTimingWaiting = false;
-			LOG((CLOG_DEBUG "game device timing request timed out"));
-		}
-		
-		// xinput controller is connected
-		if (result == ERROR_SUCCESS)
-		{
-			// @todo game device state class
-			bool buttonsChanged = state.Gamepad.wButtons != m_gameButtonsLast;
-			bool leftTriggerChanged = state.Gamepad.bLeftTrigger != m_gameLeftTriggerLast;
-			bool rightTriggerChanged = state.Gamepad.bRightTrigger != m_gameRightTriggerLast;
-			bool leftStickXChanged = state.Gamepad.sThumbLX != m_gameLeftStickXLast;
-			bool leftStickYChanged = state.Gamepad.sThumbLY != m_gameLeftStickYLast;
-			bool rightStickXChanged = state.Gamepad.sThumbRX != m_gameRightStickXLast;
-			bool rightStickYChanged = state.Gamepad.sThumbRY != m_gameRightStickYLast;
-
-			m_gameButtonsLast = state.Gamepad.wButtons;
-			m_gameLeftTriggerLast = state.Gamepad.bLeftTrigger;
-			m_gameRightTriggerLast = state.Gamepad.bRightTrigger;
-			m_gameLeftStickXLast = state.Gamepad.sThumbLX;
-			m_gameLeftStickYLast = state.Gamepad.sThumbLY;
-			m_gameRightStickXLast = state.Gamepad.sThumbRX;
-			m_gameRightStickYLast = state.Gamepad.sThumbRY;
-
-			bool eventSent = false;
-
-			if (buttonsChanged)
-			{
-				LOG((CLOG_DEBUG "xinput buttons changed"));
-
-				// xinput buttons convert exactly to synergy buttons
-				sendEvent(getGameDeviceButtonsEvent(),
-					new CGameDeviceButtonInfo(index, state.Gamepad.wButtons));
-
-				eventSent = true;
-			}
-
-			if (leftStickXChanged || leftStickYChanged || rightStickXChanged || rightStickYChanged)
-			{
-				LOG((CLOG_DEBUG "xinput sticks changed"));
-
-				sendEvent(getGameDeviceSticksEvent(),
-					new CGameDeviceStickInfo(
-					index,
-					m_gameLeftStickXLast, m_gameLeftStickYLast,
-					m_gameRightStickXLast, m_gameRightStickYLast));
-
-				eventSent = true;
-			}
-
-			if (leftTriggerChanged || rightTriggerChanged)
-			{
-				LOG((CLOG_DEBUG "xinput triggers changed"));
-
-				// @todo seems wrong re-using x/y for a single value...
-				sendEvent(getGameDeviceTriggersEvent(),
-					new CGameDeviceTriggerInfo(
-						index,
-						state.Gamepad.bLeftTrigger,
-						state.Gamepad.bRightTrigger));
-
-				eventSent = true;
-			}
-
-			if (/*eventSent && */!m_gameTimingWaiting && (ARCH->time() - m_gameLastTimingSent > .5))
-			{
-				sendEvent(getGameDeviceTimingReqEvent(), NULL);
-				m_gameLastTimingSent = ARCH->time();
-				m_gameTimingWaiting = true;
-
-				LOG((CLOG_DEBUG "game device timing request at %.4f", m_gameLastTimingSent));
-			}
-		}
-
-		UInt16 sleep = m_gamePollFreq + m_gamePollFreqAdjust;
-		LOG((CLOG_DEBUG5 "xinput poll sleeping for %dms", sleep));
-		Sleep(sleep);
-	}
-}
-
-void
-CMSWindowsScreen::xInputTimingThread(void*)
-{
-	LOG((CLOG_DEBUG "xinput timing thread started"));
-
-	bool end = false;
-	while (!end)
-	{
-		// if timing request was queued, a timing response is queued
-		// when the xinput status is faked; if it was faked, go tell
-		// the server when this happened.
-		if (DequeueXInputTimingResp())
-		{
-			LOG((CLOG_DEBUG "dequeued game device timing response"));
-			sendEvent(getGameDeviceTimingRespEvent(),
-				new CGameDeviceTimingRespInfo(GetXInputFakeFreqMillis()));
-		}
-
-		// give the cpu a break.
-		Sleep(1);
-	}
-}
-
-void
-CMSWindowsScreen::xInputFeedbackThread(void*)
-{
-	LOG((CLOG_DEBUG "xinput feedback thread started"));
-
-	int index = 0;
-	bool end = false;
-	while (!end)
-	{
-		WORD leftMotor, rightMotor;
-		if (DequeueXInputFeedback(&leftMotor, &rightMotor))
-		{
-			LOG((CLOG_DEBUG "dequeued game device feedback"));
-			sendEvent(getGameDeviceFeedbackEvent(),
-				new CGameDeviceFeedbackInfo(index, leftMotor, rightMotor));
-		}
-
-		Sleep(50);
-	}
-}
-
-#endif
-
 //
 // CMSWindowsScreen::CHotKeyItem
 //
