@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,6 +27,7 @@
 #else
 #	include <X11/Xlib.h>
 #endif
+#include "CKeyMap.h"
 
 class CXWindowsClipboard;
 class CXWindowsKeyState;
@@ -34,7 +36,7 @@ class CXWindowsScreenSaver;
 //! Implementation of IPlatformScreen for X11
 class CXWindowsScreen : public CPlatformScreen {
 public:
-	CXWindowsScreen(const char* displayName, bool isPrimary, bool disableXInitThreads, int mouseScrollDelta=0);
+	CXWindowsScreen(const char* displayName, bool isPrimary, bool disableXInitThreads, int mouseScrollDelta, IEventQueue& eventQueue);
 	virtual ~CXWindowsScreen();
 
 	//! @name manipulators
@@ -62,7 +64,7 @@ public:
 	virtual void		gameDeviceTimingResp(UInt16 freq) { }
 
 	// ISecondaryScreen overrides
-	virtual void		fakeMouseButton(ButtonID id, bool press) const;
+	virtual void		fakeMouseButton(ButtonID id, bool press);
 	virtual void		fakeMouseMove(SInt32 x, SInt32 y) const;
 	virtual void		fakeMouseRelativeMove(SInt32 dx, SInt32 dy) const;
 	virtual void		fakeMouseWheel(SInt32 xDelta, SInt32 yDelta) const;
@@ -138,6 +140,10 @@ private:
 	void				onMouseRelease(const XButtonEvent&);
 	void				onMouseMove(const XMotionEvent&);
 
+	bool				detectXI2();
+#ifdef HAVE_XI2
+	void				selectXIRawMotion();
+#endif
 	void				selectEvents(Window) const;
 	void				doSelectEvents(Window) const;
 
@@ -235,6 +241,15 @@ private:
 	bool				m_xkb;
 	int					m_xkbEventBase;
 
+	bool				m_xi2detected;
+
+	// XRandR extension stuff
+	bool                m_xrandr;
+	int                 m_xrandrEventBase;
+
+	IEventQueue&		m_eventQueue;
+	CKeyMap				m_keyMap;
+
 	// pointer to (singleton) screen.  this is only needed by
 	// ioErrorHandler().
 	static CXWindowsScreen*	s_screen;
