@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1479,6 +1480,11 @@ CXWindowsUtil::mapKeySymToKeyID(KeySym k)
 		case XK_ISO_Level3_Shift:
 			return kKeyAltGr;
 
+#ifdef XK_ISO_Level5_Shift
+		case XK_ISO_Level5_Shift:
+			return XK_ISO_Level5_Shift; //FIXME: there is no "usual" key for this...
+#endif
+
 		case XK_ISO_Next_Group:
 			return kKeyNextGroup;
 
@@ -1579,6 +1585,11 @@ CXWindowsUtil::getModifierBitForKeySym(KeySym keysym)
 	case XK_ISO_Level3_Shift:
 		return kKeyModifierBitAltGr;
 
+#ifdef XK_ISO_Level5_Shift
+	case XK_ISO_Level5_Shift:
+		return kKeyModifierBitLevel5Lock;
+#endif
+
 	case XK_Caps_Lock:
 		return kKeyModifierBitCapsLock;
 
