@@ -1,5 +1,6 @@
 /*
  * synergy -- mouse and keyboard sharing utility
+ * Copyright (C) 2012 Bolton Software Ltd.
  * Copyright (C) 2012 Nick Bolton
  * 
  * This package is free software; you can redistribute it and/or
@@ -19,6 +20,7 @@
 
 #include "CString.h"
 #include "CGameDevice.h"
+#include "CCryptoOptions.h"
 
 class CArgsBase {
 public:
@@ -36,6 +38,7 @@ public:
 	bool m_disableTray;
 	bool m_enableVnc;
 	bool m_enableIpc;
+	CCryptoOptions m_crypto;
 #if SYSAPI_WIN32
 	bool m_debugServiceWait;
 	bool m_pauseOnExit;
