@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -204,9 +205,9 @@ CClientApp::help()
 		"must be the address or hostname of the server.  The port overrides the\n"
 		"default port, %d.\n",
 		args().m_pname, kDefaultPort
-		);
+	);
 
-	std::cout << buffer << std::endl;
+	LOG((CLOG_PRINT "%s", buffer));
 }
 
 const char*
@@ -392,10 +393,10 @@ CClientApp::handleClientDisconnected(const CEvent&, void*)
 
 
 CClient*
-CClientApp::openClient(const CString& name, const CNetworkAddress& address, CScreen* screen)
+CClientApp::openClient(const CString& name, const CNetworkAddress& address, CScreen* screen, const CCryptoOptions& crypto)
 {
 	CClient* client = new CClient(
-		*EVENTQUEUE, name, address, new CTCPSocketFactory, NULL, screen);
+		EVENTQUEUE, name, address, new CTCPSocketFactory, NULL, screen, crypto);
 
 	try {
 		EVENTQUEUE->adoptHandler(
@@ -453,7 +454,7 @@ CClientApp::startClient()
 		if (s_clientScreen == NULL) {
 			clientScreen = openClientScreen();
 			s_client     = openClient(args().m_name,
-				*args().m_serverAddress, clientScreen);
+				*args().m_serverAddress, clientScreen, args().m_crypto);
 			s_clientScreen  = clientScreen;
 			LOG((CLOG_NOTE "started client"));
 		}
