@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,6 +33,8 @@
 #include "CEventQueue.h"
 #include "LogOutputters.h"
 #include "CFunctionEventJob.h"
+#include "TMethodJob.h"
+#include "CVncClient.h"
 
 #if SYSAPI_WIN32
 #include "CArchMiscWindows.h"
@@ -62,7 +65,8 @@ s_serverState(kUninitialized),
 s_serverScreen(NULL),
 s_primaryClient(NULL),
 s_listener(NULL),
-s_timer(NULL)
+s_timer(NULL),
+m_vncClient(NULL)
 {
 }
 
@@ -194,7 +198,7 @@ CServerApp::help()
 		ARCH->concatPath(ARCH->getSystemDirectory(), SYS_CONFIG_NAME).c_str()
 	);
 
-	std::cout << buffer << std::endl;
+	LOG((CLOG_PRINT "%s", buffer));
 }
 
 void
@@ -320,6 +324,13 @@ CServerApp::handleClientConnected(const CEvent&, void* vlistener)
 	if (client != NULL) {
 		s_server->adoptClient(client);
 		updateStatus();
+
+		if (args().m_enableVnc) {
+			// TODO: figure out client IP address from name.
+			CVncClient* vncClient = new CVncClient("192.168.0.13", client->getName());
+			vncClient->start();
+			m_vncClients.insert(std::pair<CString, CVncClient*>(client->getName(), vncClient));
+		}
 	}
 }
 
@@ -346,13 +357,9 @@ CServerApp::closeServer(CServer* server)
 		new TMethodEventJob<CServerApp>(this, &CServerApp::handleClientsDisconnected));
 	EVENTQUEUE->adoptHandler(CServer::getDisconnectedEvent(), server,
 		new TMethodEventJob<CServerApp>(this, &CServerApp::handleClientsDisconnected));
-	CEvent event;
-	EVENTQUEUE->getEvent(event);
-	while (event.getType() != CEvent::kQuit) {
-		EVENTQUEUE->dispatchEvent(event);
-		CEvent::deleteData(event);
-		EVENTQUEUE->getEvent(event);
-	}
+	
+	EVENTQUEUE->loop();
+
 	EVENTQUEUE->removeHandler(CEvent::kTimer, timer);
 	EVENTQUEUE->deleteTimer(timer);
 	EVENTQUEUE->removeHandler(CServer::getDisconnectedEvent(), server);
@@ -520,14 +527,14 @@ bool CServerApp::initServer()
 		return true;
 	}
 	catch (XScreenUnavailable& e) {
-		LOG((CLOG_WARN "cannot open primary screen: %s", e.what()));
+		LOG((CLOG_WARN "primary screen unavailable: %s", e.what()));
 		closePrimaryClient(primaryClient);
 		closeServerScreen(serverScreen);
-		updateStatus(CString("cannot open primary screen: ") + e.what());
+		updateStatus(CString("primary screen unavailable: ") + e.what());
 		retryTime = e.getRetryTime();
 	}
 	catch (XScreenOpenFailure& e) {
-		LOG((CLOG_CRIT "cannot open primary screen: %s", e.what()));
+		LOG((CLOG_CRIT "failed to start server: %s", e.what()));
 		closePrimaryClient(primaryClient);
 		closeServerScreen(serverScreen);
 		return false;
@@ -603,7 +610,7 @@ CServerApp::startServer()
 		listener->setServer(s_server);
 		s_listener = listener;
 		updateStatus();
-		LOG((CLOG_NOTE "started server"));
+		LOG((CLOG_NOTE "started server, waiting for clients"));
 		s_serverState = kStarted;
 		return true;
 	}
@@ -639,10 +646,11 @@ CScreen*
 CServerApp::createScreen()
 {
 #if WINAPI_MSWINDOWS
-	return new CScreen(new CMSWindowsScreen(true, args().m_noHooks, args().m_gameDevice));
+	return new CScreen(new CMSWindowsScreen(
+		true, args().m_noHooks, args().m_gameDevice, args().m_stopOnDeskSwitch));
 #elif WINAPI_XWINDOWS
 	return new CScreen(new CXWindowsScreen(
-		args().m_display, true, args().m_disableXInitThreads));
+		args().m_display, true, args().m_disableXInitThreads, 0, *EVENTQUEUE));
 #elif WINAPI_CARBON
 	return new CScreen(new COSXScreen(true));
 #endif
@@ -687,7 +695,7 @@ CClientListener*
 CServerApp::openClientListener(const CNetworkAddress& address)
 {
 	CClientListener* listen =
-		new CClientListener(address, new CTCPSocketFactory, NULL);
+		new CClientListener(address, new CTCPSocketFactory, NULL, args().m_crypto);
 	EVENTQUEUE->adoptHandler(CClientListener::getConnectedEvent(), listen,
 		new TMethodEventJob<CServerApp>(
 		this, &CServerApp::handleClientConnected, listen));
@@ -704,6 +712,10 @@ CServerApp::openServer(const CConfig& config, CPrimaryClient* primaryClient)
 			CServer::getDisconnectedEvent(), server,
 			new TMethodEventJob<CServerApp>(this, &CServerApp::handleNoClients));
 
+		EVENTQUEUE->adoptHandler(
+			CServer::getScreenSwitchedEvent(), server,
+			new TMethodEventJob<CServerApp>(this, &CServerApp::handleScreenSwitched));
+
 	} catch (std::bad_alloc &ba) {
 		delete server;
 		throw ba;
@@ -712,20 +724,42 @@ CServerApp::openServer(const CConfig& config, CPrimaryClient* primaryClient)
 	return server;
 }
 
-void CServerApp::handleNoClients( const CEvent&, void* )
+void
+CServerApp::handleNoClients(const CEvent&, void*)
 {
 	updateStatus();
 }
 
-int CServerApp::mainLoop()
+void
+CServerApp::handleScreenSwitched(const CEvent& e, void*)
+{
+	if (!args().m_enableVnc)
+		return;
+
+	if (m_vncClient != NULL) {
+		LOG((CLOG_DEBUG "hiding vnc viewer for: %s", m_vncClient->m_screen.c_str()));
+		m_vncClient->hideViewer();
+	}
+
+	CServer::CSwitchToScreenInfo* info = reinterpret_cast<CServer::CSwitchToScreenInfo*>(e.getData());
+	std::map<CString, CVncClient*>::iterator it = m_vncClients.find(info->m_screen);
+	if (it == m_vncClients.end()) {
+		LOG((CLOG_DEBUG "could not find vnc client for: %s", info->m_screen));
+		return;
+	}
+
+	LOG((CLOG_DEBUG "showing vnc viewer for: %s", info->m_screen));
+	m_vncClient = it->second;
+	m_vncClient->showViewer();
+}
+
+int
+CServerApp::mainLoop()
 {
 	// create socket multiplexer.  this must happen after daemonization
 	// on unix because threads evaporate across a fork().
 	CSocketMultiplexer multiplexer;
 
-	// create the event queue
-	CEventQueue eventQueue;
-
 	// if configuration has no screens then add this system
 	// as the default
 	if (args().m_config->begin() == args().m_config->end()) {
@@ -750,7 +784,16 @@ int CServerApp::mainLoop()
 	}
 
 	// start server, etc
-	ARCH->util().startNode();
+	appUtil().startNode();
+	
+	// init ipc client after node start, since create a new screen wipes out
+	// the event queue (the screen ctors call adoptBuffer).
+	if (argsBase().m_enableIpc) {
+		initIpcClient();
+	}
+
+	// load all available plugins.
+	ARCH->plugin().init(s_serverScreen->getEventTarget());
 
 	// handle hangup signal by reloading the server's configuration
 	ARCH->setSignalHandler(CArch::kHANGUP, &reloadSignalHandler, NULL);
@@ -773,14 +816,8 @@ int CServerApp::mainLoop()
 	// run event loop.  if startServer() failed we're supposed to retry
 	// later.  the timer installed by startServer() will take care of
 	// that.
-	CEvent event;
 	DAEMON_RUNNING(true);
-	EVENTQUEUE->getEvent(event);
-	while (event.getType() != CEvent::kQuit) {
-		EVENTQUEUE->dispatchEvent(event);
-		CEvent::deleteData(event);
-		EVENTQUEUE->getEvent(event);
-	}
+	EVENTQUEUE->loop();
 	DAEMON_RUNNING(false);
 
 	// close down
@@ -793,6 +830,10 @@ int CServerApp::mainLoop()
 	updateStatus();
 	LOG((CLOG_NOTE "stopped server"));
 
+	if (argsBase().m_enableIpc) {
+		cleanupIpcClient();
+	}
+
 	return kExitSuccess;
 }
 
