@@ -1,6 +1,7 @@
 /*
  * synergy -- mouse and keyboard sharing utility
- * Copyright (C) 2002 Chris Schoeneman, Nick Bolton, Sorin Sbarnea
+ * Copyright (C) 2012 Bolton Software Ltd.
+ * Copyright (C) 2002 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -282,6 +283,11 @@ extern const char*		kMsgDInfo;
 // pairs.
 extern const char*		kMsgDSetOptions;
 
+// crypto iv:  primary -> secondary
+// sends a new iv (initialization vector) to the client for the
+// cryptography stream.
+extern const char*		kMsgDCryptoIv;
+
 //
 // query codes
 //
